@@ -3,14 +3,15 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
+from pollination_sdk.api.api_tokens_api import APITokensApi
 from pollination_sdk.api.accounts_api import AccountsApi
 from pollination_sdk.api.artifacts_api import ArtifactsApi
-from pollination_sdk.api.operators_api import OperatorsApi
+from pollination_sdk.api.jobs_api import JobsApi
 from pollination_sdk.api.orgs_api import OrgsApi
+from pollination_sdk.api.plugins_api import PluginsApi
 from pollination_sdk.api.projects_api import ProjectsApi
 from pollination_sdk.api.recipes_api import RecipesApi
 from pollination_sdk.api.registries_api import RegistriesApi
-from pollination_sdk.api.simulations_api import SimulationsApi
 from pollination_sdk.api.teams_api import TeamsApi
 from pollination_sdk.api.user_api import UserApi
 from pollination_sdk.api.users_api import UsersApi
